#!/usr/bin/env python
# coding:utf-8

import requests
from hashlib import md5


class Chaojiying_Client(object):

    def __init__(self, username, password, soft_id):
        self.username = username
        password = password.encode('utf8')
        self.password = md5(password).hexdigest()
        self.soft_id = soft_id
        self.base_params = {
            'user': self.username,
            'pass2': self.password,
            'softid': self.soft_id,
        }
        self.headers = {
            'Connection': 'Keep-Alive',
            'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)',
        }

    def PostPic(self, im, codetype):
        """
        im: 图片字节
        codetype: 题目类型 参考 http://www.chaojiying.com/price.html
        """
        params = {
            'codetype': codetype,
        }
        params.update(self.base_params)
        files = {'userfile': ('ccc.jpg', im)}
        r = requests.post('http://upload.chaojiying.net/Upload/Processing.php', data=params, files=files,
                          headers=self.headers)
        return r.json()

    def ReportError(self, im_id):
        """
        im_id:报错题目的图片ID
        """
        params = {
            'id': im_id,
        }
        params.update(self.base_params)
        r = requests.post('http://upload.chaojiying.net/Upload/ReportError.php', data=params, headers=self.headers)
        return r.json()


class Verification:

    def verification_code(self, username, password, soft_id, im, mode=1902):
        chaojiying = Chaojiying_Client(username, password, soft_id)  # 用户中心>>软件ID 生成一个替换 96001
        # im = open(img_src, 'rb').read()  # 本地图片文件路径 来替换 a.jpg 有时WIN系统须要//
        code = chaojiying.PostPic(im, mode)  # 1902 验证码类型  官方网站>>价格体系 3.4+版 print 后要加()
        return code




# !/usr/bin/env python
# -*-coding:utf-8 -*-

# windows 系统如需要登录时取消注释
# import win32com.client
#
#
# class RegDm:
#     """
#     大漠对象注册
#     """
#
#     @classmethod
#     def reg(cls):
#         dm = win32com.client.Dispatch('dm.dmsoft')
#         return dm




# !/usr/bin/env python
# -*-coding:utf-8 -*-


import time
import random

import pyautogui
import pyperclip


# 随机数等待时间
class Delay:
    @classmethod
    def delay(cls, rand_start_time=0.3, rand_end_time=0.8):
        """
        随机延迟, 默认 0.5 ~ 1 之间随机
        :return:
        """
        random.seed(time.time())
        rand_time = random.uniform(rand_start_time, rand_end_time)
        time.sleep(rand_time)


# 模拟输入法中文操作
class Enter_Ch:
    @classmethod
    def insert(cls,sub):
        """
        :param sub: 需要打印的内容
        :type sub: str
        :return:
        :rtype:
        """
        pyperclip.copy(sub)
        pyautogui.hotkey('ctrl', 'v')



from time import sleep
import os
import sys
import cv2
import pyautogui
from .adb.Command_adb import command
from PIL import Image


# 截图
def screen_shot(fol_path):
    sleep(0.1)
    pyautogui.screenshot(fol_path)


# 当前页面找图,找到匹配对象位置中心点
def find_image(fol_path, target_path, _system=None, int_x1=0, int_y1=None, int_x2=None, int_y2=None):
    """
    在当前页面上找目标图片坐在坐标，返回中心坐标 (x,y)
    :param path:
    :param target: 例：../img/test.png
    :return:
    """
    if _system == 'hwnd':  # hwnd暂时没更新进来
        pass
    elif _system == 'adb':  # android adb 截图
        cut = command()
        # print(fol_path.split('\\')[-1])
        cut.cut_scr(fol_path)
    elif _system is None:  # pyautogui 截图
        screen_shot(fol_path)
    # 获取当前页面的截图
    source_path = os.path.join(fol_path)
    if int_x1 == 0:
        pass
    else:
        img = Image.open(source_path)
        code_image = img.crop((int_x1, int_y1, int_x2, int_y2))
        code_image.save(source_path)  # 原地址重写

    # 获取目标图片的存放路径
    target_path = os.path.join(target_path)
    # print(source_path)
    # print(target_path)

    source_image = cv2.imread(source_path)
    target_image = cv2.imread(target_path)

    # 使用 TM_CCOEFF_NORMED 获取目标图片与原图片的每个点的匹配度
    result = cv2.matchTemplate(source_image, target_image, cv2.TM_CCOEFF_NORMED)

    # 找出匹配度最高的点和最低的点，并返回对应的坐标
    match_result = cv2.minMaxLoc(result)

    if match_result[1] > 0.9:  # 匹配度大于90%，视为匹配成功
        pos_start = cv2.minMaxLoc(result)[3]  # 获取匹配成功后的起始坐标

        # 计算匹配对象的中心位置坐标
        x = int(pos_start[0]) + int(target_image.shape[1]) / 2
        y = int(pos_start[1]) + int(target_image.shape[0]) / 2
        if sys.platform == 'darwin':
            if int_x1 == 0:
                return x / 2, y / 2
            else:
                return (x + int_x1) / 2, (y + int_y1) / 2
        else:
            if int_x1 == 0:
                return x, y
            else:
                return (x + int_x1), (y + int_y1)
    else:
        return None





# -*coding:utf-8 -*-
# !/usr/bin/env python
import pickle
from Lshengpackage.tools.Loading import load_click, load, insclick
from Lshengpackage.simulate.mock_findPic import find_image
from PIL import Image


def start_picdata(pypath):
    global image_data
    with open(pypath, 'rb') as f:
        image_data = pickle.load(f)


def read_img(path, img_name):
    # 读取py的图片并缓存为临时文件
    img_data = image_data[img_name][0]
    img = Image.new(mode='RGB', size=(img_data['width'], img_data['height']))
    img.putdata(img_data['pixel_values'])
    img.save(path + 'public.png')


def refind_image(fol_path, path, img_name, _system=None, int_x1=-1, int_y1=None, int_x2=None, int_y2=None):
    read_img(path, img_name)
    pub = find_image(fol_path, path + 'public.png', _system, int_x1, int_y1, int_x2, int_y2)
    if pub is not None:
        return pub


def refiloadclick_image(fol_path, path, img_name, _system):
    read_img(path, img_name)
    pub = load_click(fol_path, path + 'public.png', _system)  # 退出当前页再找
    if pub is True:
        return True
    else:
        return False


def refiload_image(fol_path, path, img_name, _system):
    read_img(path, img_name)
    pub = load(fol_path, path + 'public.png', _system)  # 退出当前页再找
    if pub is not None:
        return pub


def refiinsclick_image(fol_path, path, img_name, _system):
    read_img(path, img_name)
    pub = insclick(fol_path, path + 'public.png', _system)  # 退出当前页再找
    if pub is True:
        return True
    else:
        return False



# -*- coding: UTF-8 -*-
import pytesseract
from PIL import Image

# tesseract.exe所在的文件路径
def fr(img):
    # 读取图片
    img = Image.open(img)
    config = r'-l chi_sim+eng --psm 6'
    frc = pytesseract.image_to_string(img, config=config)
    return frc




# -*- coding: UTF-8 -*-

# 检索目录下文件
import os

import pandas as pd

global road


# 找文件
def search_it(paths, filename):
    
    global road  # 表明这里的road是全局变量road
    
    # 检查给定路径是否存在,不存在会因为报错而退出
    try:
        file_lis = os.listdir(paths)
    except:
        return False
    
    # 获取文件路径列表,暴力就是在所有的文件路径中进行比对
    file_lis = os.listdir(paths)
    
    if file_lis.__contains__(filename):  # 判断是否在当前路径下
        # 控制台输出路劲
        road = os.path.join(paths, filename)
        # 如果找到，返回True
        return True
    else:  # 不在就打开其下的文件夹,继续往下找
        for item in file_lis:
            # 递归的查找这个文件
            if search_it(os.path.join(paths, item), filename):
                return True
        return False


def search_in_csv(filename):
    pa = pd.read_csv('path_.csv')
    for i in pa:
        if i.split('|')[0] == filename:
            path = i.split('|')[1]
            return path


def _find_file_path(paths, filename):
    if not search_it(paths, filename):
        return False
    else:
        global road
        data_ = filename + '|' + road
        data = [data_]
        scr = pd.DataFrame(data=data)
        scr.to_csv('path_.csv', index=False, header=False)
        return road


# 首次找出路径并保存到存档，会需要点时间
def searchfile_path(paths, filename):
    if os.path.exists('path_.csv'):
        path = search_in_csv(filename)
        if path:
            return path
        else:
            _find_file = _find_file_path(paths, filename)
            if _find_file:
                return _find_file
            else:
                return False
    
    else:
        _find_file = _find_file_path(paths, filename)
        if _find_file:
            return _find_file
        else:
            return False



# -*- coding: UTF-8 -*-
import os
import pickle
from time import sleep

from Lshengpackage.simulate.adb.Command_adb import command
from Lshengpackage.simulate.mock_findPic import find_image
from Lshengpackage.tools.Loading import load_click, load, insclick
from PIL import Image


def start_picdata(pypath):
    global image_data
    with open(pypath, 'rb') as f:
        image_data = pickle.load(f)


def read_img(path, img_name):
    # 读取py的图片并缓存为临时文件
    img_data = image_data[img_name][0]
    img = Image.new(mode='RGB', size=(img_data['width'], img_data['height']))
    img.putdata(img_data['pixel_values'])
    img.save(path + 'public.png')


def refind_image(fol_path, path, img_name, _system=None, int_x1=-1, int_y1=None, int_x2=None, int_y2=None):
    read_img(path, img_name)
    pub = find_image(fol_path, path + 'public.png', _system, int_x1, int_y1, int_x2, int_y2)
    if pub is not None:
        return pub


def refiloadclick_image(fol_path, path, img_name, _system):
    read_img(path, img_name)
    pub = load_click(fol_path, path + 'public.png', _system)  # 退出当前页再找
    if pub is True:
        return True
    else:
        return False


def refiload_image(fol_path, path, img_name, _system):
    read_img(path, img_name)
    pub = load(fol_path, path + 'public.png', _system)  # 退出当前页再找
    if pub is not None:
        return pub


def refiinsclick_image(fol_path, path, img_name, _system):
    read_img(path, img_name)
    pub = insclick(fol_path, path + 'public.png', _system)  # 退出当前页再找
    if pub is True:
        return True
    else:
        return False


# 检测当前连接状态
def connect_status_api():
    state = os.popen('adb get-state').read()  # ddddddddddd
    if state[0:7] == 'unknown':
        print('未检测到连接设备')
        return False
    elif state[0:6] == 'device':
        print('设备连接正常')
        return True
    else:
        print('设备无响应,请重启设备尝试')


# 连接adb
def connect_api(ip):
    connect = os.system('adb connect {}'.format(ip))
    if connect == 0:
        txt = '连接设备{},成功'.format(ip)
        # print(txt)
        return txt


# 检测dingding当前界面
def ding_current_api(fol_path, path, _system):
    # Lshengpackage.simulate.adb.Command_adb.command().tap_work(419,953)
    sleep(0.1)
    if refind_image(fol_path, path, 'is_msg', _system) is not None:
        print('******当前页面为消息页******')
        return '消息页'
    elif refind_image(fol_path, path, 'is_tooge', _system) is not None:
        print('******当前页面为协作页******')
        return '协作页'
    elif refind_image(fol_path, path, 'is_work', _system) is not None:
        print('******当前页面为办公页******')
        return '办公页'
    elif refind_image(fol_path, path, 'is_iph', _system) is not None:
        print('******当前页面为通讯页******')
        return '通讯页'
    elif refind_image(fol_path, path, 'is_my', _system) is not None:
        print('******当前页面为个人页******')
        return '个人页'
    elif refind_image(fol_path, path, 'is_exa', _system) is not None:
        print('******当前页面为自查页,立即返回主程序******')

        refiinsclick_image(fol_path, path, 'tureok', _system)
        refiinsclick_image(fol_path, path, 'exit', _system)
        sleep(0.1)
        ding_current_api(fol_path, path, _system)
    elif refind_image(fol_path, path, 'is_answer', _system) is not None:
        print('******当前页面为答题页,立即返回主程序******')
        refiinsclick_image(fol_path, path, 'tureok', _system)
        refiloadclick_image(fol_path, path, 'exit', _system)
        sleep(0.1)
        ding_current_api(fol_path, path, _system)


# 打开应用接口 #答题 op_answer.png 自查 op_exaself.png
def open_app_api(fol_path, path, _system, op_name):  # op_name op的名
    xy = refiinsclick_image(fol_path, path, 'is_work', _system)
    if xy is False:
        refiinsclick_image(fol_path, path, 'work', _system)
    else:
        pass
    op_answer = refiinsclick_image(fol_path, path, op_name, _system)
    if op_answer is False:
        is_work = refind_image(fol_path, path, 'is_work', _system)
        if is_work is not None:
            command().swip_work(int(is_work[0]), int(is_work[1] - 400), int(is_work[0]), int(is_work[1]))
    else:
        sleep(1)
        op_answer = refiinsclick_image(fol_path, path, op_name, _system)
        print('{}页已打开,持续更近中'.format(op_name))
        return True
    for i in range(2):
        op_answer = refind_image(fol_path, path, op_name, _system)
        if op_answer is False:
            sleep(0.1)
            is_work = refind_image(fol_path, path, 'is_work', _system)
            command().swip_work(int(is_work[0]), int(is_work[1] - 100), int(is_work[0]), int(is_work[1] - 500))
        else:
            op_answer = refiinsclick_image(fol_path, path, op_name, _system)
            print('{}页已打开,持续更近中'.format(op_name))
            return True


# 安全答题程序执行程序接口
def do_answer_api(fol_path, path, _system):
    refiload_image(fol_path, path, 'do_answer', _system)
    sleep(0.5)

    do_fi_answer = refind_image(fol_path, path, 'do_fi_answer', _system)
    if do_fi_answer is not None:  # 处理上次记忆时间
        pass
    else:
        refiloadclick_image(fol_path, path, 'do_answer', _system)
    refiinsclick_image(fol_path, path, 'do_fi_answer', _system)
    sleep(0.1)

    lo = refiload_image(fol_path, path, 'do_fi_ti_answer', _system)  # 加载
    v = 0
    for i in range(5):
        v += 1
        refiinsclick_image(fol_path, path, 'push', _system)  # 加载

        _upup(fol_path, path, _system, a=v)

        answer(fol_path, path, _system)
    refiloadclick_image(fol_path, path, 'update', _system)
    refiload_image(fol_path, path, 'answer_over', _system)
    print('答题成功！！！')
    refiinsclick_image(fol_path, path, 'exit', _system)  # 加载
    refiloadclick_image(fol_path, path, 'ose', _system)


def _upup(fol_path, path, _system, a):
    while True:

        sh = refiload_image(fol_path, path, 'shouqi', _system)  # 加载
        print(sh)
        command().swip_work(int(sh[0]), int(sh[1]), int(sh[0]), int(sh[1] - 100))

        pu = refind_image(fol_path, path, 'push', _system)  # 加载
        print(pu)
        if pu is not None:
            return True
        else:
            if a == 5:
                command().swip_work(int(sh[0]), int(sh[1]), int(sh[0]), int(sh[1] - 500))
                return True


def answer(fol_path, path, _system):
    for i in ['A', 'B', 'C', 'D']:

        select = refind_image(fol_path, path, 'select', _system, int_x1=0, int_y1=540, int_x2=1920,
                              int_y2=1080)
        command().tap_work(int(select[0]), int(select[1] + 40))
        refiloadclick_image(fol_path, path, '{}'.format(i), _system)  # 加载
        sleep(0.2)

        yesok = refind_image(fol_path, path, 'yesok', _system, int_x1=0, int_y1=540, int_x2=1920,
                             int_y2=1080)
        if yesok is not None:
            return True


# 每日安全自查程序接口
def do_checkself_api(fol_path, path, _system):
    refiloadclick_image(fol_path, path, 'city', _system)
    refiloadclick_image(fol_path, path, 'jiujiang', _system)
    refiloadclick_image(fol_path, path, 'district', _system)
    refiloadclick_image(fol_path, path, 'lianxiqu', _system)
    att = refiload_image(fol_path, path, 'attribute', _system)
    command().tap_work(int(att[0]), int(att[1]))
    refiloadclick_image(fol_path, path, 'safeguard', _system)
    refiloadclick_image(fol_path, path, 'specialized', _system)
    refiloadclick_image(fol_path, path, 'guest', _system)

    command().swip_work(int(att[0]), int(att[1]), int(att[0]), int(att[1] - 60))

    te = refiload_image(fol_path, path, 'temp', _system)
    command().tap_work(int(te[0]), int(te[1] + 20))
    sleep(1)
    os.popen('adb shell input text 36')  # 输入文本
    while True:
        command().swip_work(int(te[0]), int(te[1]), int(te[0]), int(te[1] - 150))
        for i in range(5):
            ye = refiinsclick_image(fol_path, path, 'yes', _system)
            if ye is False:
                break
        sleep(0.1)

        ye = refind_image(fol_path, path, 'saferope', _system)
        if ye is not None:
            break
    refiloadclick_image(fol_path, path, 'update', _system)
    refiload_image(fol_path, path, 'selfsafe_over', _system)
    print('自查成功！！！')
    refiinsclick_image(fol_path, path, 'exit', _system)



# 全局变量
# coding:utf-8
# !/usr/bin/env python#

class windows:
    def __init__(self, dm_obj):
        self.__dm_obj = dm_obj

    def hwnd_windows(self, name, taxon, rank):
        # rank 1+2+4+8+16
        hwnd_window = int(self.__dm_obj.EnumWindow(0, name, taxon, rank))
        return hwnd_window

    def down_windows(self, hwnd):
        down_window = self.__dm_obj.SetWindowState(hwnd, 1)
        return down_window

    def open_windows(self, hwnd):
        open_window = self.__dm_obj.ForceUnBindWindow(hwnd)
        return open_window

    def bind_windows(self, hwnd, type_windows, type_mouse, type_keyboard, public, mode):
        dm_bind = self.__dm_obj.BindWindowEx(hwnd, type_windows, type_mouse, type_keyboard, public, mode)
        return dm_bind

        #     "normal": 正常模式, 平常我们用的前台截屏模式
        #     "gdi": "gdi2": "dx2": "dx3": dx3模式
        #     dx模式, 用于窗口采用dx模式刷新, 取值可以是以下任意组合，组合采用
        #     "dx.graphic.2d" "dx.graphic.2d.2""dx.graphic.3d""dx.graphic.3d.8""dx.graphic.opengl"
        #     "dx.graphic.opengl.esv2""dx.graphic.3d.10plus"

        #     mouse
        #     1."normal": 正常模式, 平常我们用的前台鼠标模式
        #     2."windows": Windows模式, 采取模拟windows消息方式
        #     3."windows3": Windows3模式，采取模拟windows消息方式, 可以支持有多个子窗口的窗口后台

        #     1."dx.mouse.position.lock.api"此模式表示通过封锁系统API，来锁定鼠标位置.
        #     2."dx.mouse.position.lock.message"此模式表示通过封锁系统消息，来锁定鼠标位置.
        #     3."dx.mouse.focus.input.api"此模式表示通过封锁系统API来锁定鼠标输入焦点.
        #     4."dx.mouse.focus.input.message"此模式表示通过封锁系统消息来锁定鼠标输入焦点.
        #     5"dx.mouse.clip.lock.api"此模式表示通过封锁系统API来锁定刷新区域。注意，使用这个模式，在绑定前，必须要让窗口完全显示出来.
        #     6."dx.mouse.input.lock.api"此模式表示通过封锁系统API来锁定鼠标输入接口.
        #     7."dx.mouse.state.api"此模式表示通过封锁系统API来锁定鼠标输入状态.
        #     8."dx.mouse.state.message"此模式表示通过封锁系统消息来锁定鼠标输入状态.
        #     9."dx.mouse.api"此模式表示通过封锁系统API来模拟dx鼠标输入.
        #     10."dx.mouse.cursor"开启此模式，可以后台获取鼠标特征码.
        #     11."dx.mouse.raw.input"有些窗口需要这个才可以正常操作鼠标.
        #     12."dx.mouse.input.lock.api2"部分窗口在后台操作时，前台鼠标会移动, 需要这个属性.
        #     13."dx.mouse.input.lock.api3"部分窗口在后台操作时，前台鼠标会移动, 需要这个属性.
        #
        #     keypad
        #     "normal": 正常模式, 平常我们用的前台键盘模式
        #     "windows": Windows模式, 采取模拟windows消息方式
        #     同按键的后台插件.
        #     1."dx.keypad.input.lock.api"此模式表示通过封锁系统API来锁定键盘输入接口.
        #     2."dx.keypad.state.api"此模式表示通过封锁系统API来锁定键盘输入状态.
        #     3."dx.keypad.api"
        #     此模式表示通过封锁系统API来模拟dx键盘输入.
        #     4."dx.keypad.raw.input"有些窗口需要这个才可以正常操作键盘.
        #
        #     public
        #     1."dx.public.active.api"此模式表示通过封锁系统API来锁定窗口激活状态.注意，部分窗口在此模式下会耗费大量资源慎用.
        #     2."dx.public.active.message"此模式表示通过封锁系统消息来锁定窗口激活状态.注意，部分窗口在此模式下会耗费大量资源慎用.
        #     另外如果要让此模式生效，必须在绑定前，让绑定窗口处于激活状态, 否则此模式将失效.比如dm.SetWindowStatehwnd, 1然后再绑定.
        #     3."dx.public.disable.window.position"此模式将锁定绑定窗口位置.不可与"dx.public.fake.window.min"共用.
        #     4."dx.public.disable.window.size"此模式将锁定绑定窗口, 禁止改变大小.不可与"dx.public.fake.window.min"共用.
        #     5."dx.public.disable.window.minmax"此模式将禁止窗口最大化和最小化, 但是付出的代价是窗口同时也会被置顶.不可与"dx.public.fake.window.min"共用.
        #     6."dx.public.fake.window.min"此模式将允许目标窗口在最小化状态时，仍然能够像非最小化一样操作..另注意，此模式会导致任务栏顺序重排，
        #     所以如果是多开模式下，会看起来比较混乱，建议单开使用，多开不建议使用.同时此模式不是万能的, 有些情况下最小化以后图色会不刷新或者黑屏.
        #     7."dx.public.hide.dll"此模式将会隐藏目标进程的大漠插件，避免被检测..另外使用此模式前，请仔细做过测试，此模式可能会造成目标进程不稳定，出现崩溃。
        #     8."dx.public.active.api2"此模式表示通过封锁系统API来锁定窗口激活状态.部分窗口遮挡无法后台, 需要这个属性.
        #     9."dx.public.input.ime"此模式是配合SendStringIme使用.具体可以查看SendStringIme接口.
        #     10
        #     "dx.public.graphic.protect"
        #     此模式可以保护dx图色不被恶意检测.同时对dx.keypad.api和dx.mouse.api也有保护效果.这个参数可能会导致某些情况下目标图色失效.一般出现在场景重新加载的时候.重新绑定会恢复.
        #     11"dx.public.disable.window.show"禁止目标窗口显示, 这个一般用来配合dx.public.fake.window.min来使用.
        #     12"dx.public.anti.api"此模式可以突破部分窗口对后台的保护.
        #     13"dx.public.km.protect"此模式可以保护dx键鼠不被恶意检测.最好配合dx.public.anti.api一起使用.此属性可能会导致部分后台功能失效.
        #     14"dx.public.prevent.block"绑定模式1 3 5 7 101 103下，可能会导致部分窗口卡死.这个属性可以避免卡死.
        #     15"dx.public.ori.proc"此属性只能用在模式0 1 2 3 和101下.有些窗口在不同的界面下(比如登录界面和登录进以后的界面)，
        #     键鼠的控制效果不相同.那可以用这个属性来尝试让保持一致.注意的是，这个属性不可以滥用，确保测试无问题才可以使用.否则可能会导致后台失效.
        #     16"dx.public.down.cpu"此模式可以配合DownCpu来降低目标进程CPU占用.当图色方式降低CPU无效时，可以尝试此种方式.需要注意的是，
        #     当使用此方式降低CPU时，会让图色方式降低CPU失效
        #     17"dx.public.focus.message"当后台绑定后, 后台无法正常在焦点窗口输入文字时, 可以尝试加入此属性.此属性会强制键盘消息发送到焦点窗口.
        #     慎用此模式, 此模式有可能会导致后台键盘在某些情况下失灵.
        #     18"dx.public.graphic.speed"只针对图色中的dx模式有效.此模式会牺牲目标窗口的性能，来提高DX图色速度，尤其是目标窗口刷新很慢时，这个参数就很有用了.
        #     19"dx.public.memory"让本对象突破目标进程防护, 可以正常使用内存接口.当用此方式使用内存接口时，内存接口的速度会取决于目标窗口的刷新率.
        #     20"dx.public.inject.super"突破某些难以绑定的窗口.此属性仅对除了模式0和2的其他模式有效.
        #     21"dx.public.hack.speed"类似变速齿轮，配合接口HackSpeed使用
        #     22"dx.public.inject.c"突破某些难以绑定的窗口.此属性仅对除了模式0和2的其他模式有效.
        #
        #     mode
        #     0: 推荐模式此模式比较通用，而且后台效果是最好的.
        #     2: 同模式0, 如果模式0有崩溃问题，可以尝试此模式.注意0和2模式，当主绑定(第一个绑定同个窗口的对象)绑定成功后，那么调用主绑定的线程必须一直维持, 否则线程一旦推出, 对应的绑定也会消失.
        #     101: 超级绑定模式.可隐藏目标进程中的dm.dll.避免被恶意检测.效果要比dx.public.hide.dll好.推荐使用.
        #     103: 同模式101，如果模式101有崩溃问题，可以尝试此模式.
        #     11: 需要加载驱动, 适合一些特殊的窗口, 如果前面的无法绑定，可以尝试此模式.此模式不支持32位系统
        #     13: 需要加载驱动, 适合一些特殊的窗口, 如果前面的无法绑定，可以尝试此模式.此模式不支持32位系统
        # 需要注意的是: 模式101 103在大部分窗口下绑定都没问题。但也有少数特殊的窗口，比如有很多子窗口的窗口，对于这种窗口，在绑定时，
        # 一定要把鼠标指向一个可以输入文字的窗口，比如一个文本框，最好能激活这个文本框，这样可以保证绑定的成功.



# !/usr/bin/env python
# -*-coding:utf-8 -*-


from Lshengpackage.simulate import mock_findFr
from Lshengpackage.simulate import mock_findPic
from Lshengpackage.simulate.adb import Command_adb
from Lshengpackage.simulate.adb import re_Pic
from Lshengpackage.simulate.adb.dingtalk import dingtalk_api
from Lshengpackage.simulate.adb.dingtalk import image_data
from Lshengpackage.simulate.dm import Pac_dm
from Lshengpackage.simulate.dm import Reg
from Lshengpackage.simulate.dm import Win_dm
from Lshengpackage.tools import ChaoJiYing
from Lshengpackage.tools import General
from Lshengpackage.tools import Loading
from Lshengpackage.tools import OperateFile
from Lshengpackage.tools import SearchFile



# -*- coding: UTF-8 -*-

from Lshengpackage.Delay import Delay


class mouse:
    def __init__(self, dm_obj, start_time=0.3, end_time=0.7):
        self.__dm_obj = dm_obj
        self.start_time = start_time
        self.end_time = end_time

    def lClick(self):
        """
        左键点击
        """
        Delay.delay(self.start_time, self.end_time)
        self.__dm_obj.LeftClick()

    def rClick(self):
        """
        右键点击
        """
        Delay.delay(self.start_time, self.end_time)
        self.__dm_obj.RightClick()

    def move_lClick(self, int_x, int_y):
        """
        移动并点击
        """
        self.__dm_obj.MoveTo(int_x, int_y)
        Delay.delay(self.start_time, self.end_time)
        self.lClick()

    def move_double_click(self, int_x, int_y):
        """
        移动并双击
        """
        self.__dm_obj.MoveTo(int_x, int_y)
        Delay.delay(self.start_time, self.end_time)
        self.__dm_obj.LeftDoubleClick()


class color:
    def __init__(self, dm_obj):
        self.__dm_obj = dm_obj

    def find_color(self, int_x1, int_y1, int_x2, int_y2, color, sim=0.9, direct=0):
        # dir 整形数:查找方向 0: 从左到右,从上到下
        # 1: 从左到右,从下到上
        # 2: 从右到左,从上到下
        # 3: 从右到左,从下到上
        # 4：从中心往外查找
        # 5: 从上到下,从左到右
        # 6: 从上到下,从右到左
        # 7: 从下到上,从左到右
        # 8: 从下到上,从右到左
        dm_ret = self.__dm_obj.FindColor(int_x1, int_y1, int_x2, int_y2, color, sim, direct)
        return dm_ret

    def find_color_click(self, int_x1, int_y1, int_x2, int_y2, color, sim=0.9, direct=0):
        """
        找色 并 点击
        :param int_x1:
        :param int_y1:
        :param int_x2:
        :param int_y2:
        :param color: 色彩格式
        :param sim:
        :param direct:
        :return: 成功 1, 失败 0
        """
        dm_ret = self.__dm_obj.FindColor(int_x1, int_y1, int_x2, int_y2, color, sim, direct)
        if dm_ret[-1] == -1:
            return
        else:
            int_x = dm_ret[0]
            int_y = dm_ret[1]
            mouse(self.__dm_obj).move_lClick(int_x, int_y)
            return 1


class pic:
    def __init__(self, dm_obj):
        self.__dm_obj = dm_obj

    def find_pic(self, int_x1, int_y1, int_x2, int_y2, pic_name, delta_color='000000', sim=0.9, direct=0):
        # dir 整形数:查找方向 0: 从左到右,从上到下 1: 从左到右,从下到上 2: 从右到左,从上到下 3: 从右到左, 从下到上
        """
        找图
        :param int_x1:
        :param int_y1:
        :param int_x2:
        :param int_y2:
        :param pic_name:
        :param delta_color:
        :param sim:
        :param direct:
        :return: 成功 返回坐标, 失败 -1, -1, -1
        """
        dm_ret = self.__dm_obj.FindPicE(int_x1, int_y1, int_x2, int_y2, pic_name, delta_color, sim, direct)
        return dm_ret

    def find_pic_click(self, int_x1, int_y1, int_x2, int_y2, pic_name, delta_color='000000', sim=0.9, direct=0):
        """
        找图并点击
        :return: 成功 1, 失败 0
        """
        dm_ret = self.__dm_obj.FindPicE(int_x1, int_y1, int_x2, int_y2, pic_name, delta_color, sim, direct)
        if dm_ret[-1] == -1:
            return
        else:
            int_x = dm_ret[1]
            int_y = dm_ret[-1]
            mouse(self.__dm_obj).move_lClick(int_x, int_y)
            return 1


class word:
    def __init__(self, dm_obj):
        self.__dm_obj = dm_obj

    def find_word(self, int_x1, int_y1, int_x2, int_y2, str_name, color_format, sim=0.8):
        """
        找字
        """
        dm_ret = self.__dm_obj.FindStrFast(int_x1, int_y1, int_x2, int_y2, str_name, color_format, sim)
        return dm_ret

    def find_word_click(self, int_x1, int_y1, int_x2, int_y2, str_name, color_format, sim=0.8):
        """
        找字并点击
        :param int_x1:
        :param int_y1:
        :param int_x2:
        :param int_y2:
        :param str_name:
        :param color_format:
        :param sim:
        :return: 成功 1, 失败 0
        """
        dm_ret = self.__dm_obj.FindStrFast(int_x1, int_y1, int_x2, int_y2, str_name, color_format, sim)
        if dm_ret[-1] == -1:
            return
        else:
            int_x = dm_ret[0]
            int_y = dm_ret[1]
            mouse(self.__dm_obj).move_lClick(int_x, int_y)
            return 1



# -*- coding: UTF-8 -*-
import os
from collections import defaultdict
from openpyxl import Workbook, load_workbook
import pandas as pd

# 删除文件夹下所有文件
def del_Files(dir_path):
    """
    :param dir_path: 文件夹路径
    :type dir_path:  str
    :return:
    :rtype:
    """
    if os.path.isfile(dir_path):
        try:
            os.remove(dir_path)  # 这个可以删除单个文件，不能删除文件夹
        except BaseException as e:
            return e
    elif os.path.isdir(dir_path):
        file_lis = os.listdir(dir_path)
        for file_name in file_lis:
            # if file_name != 'wibot.log':
            tf = os.path.join(dir_path, file_name)
            del_Files(tf)
        return True


# 获取文件夹下所有文件名
def file_in_Fol(file_path):
    file_name_list = defaultdict(list)
    """
    :param file_path:  文件夹路径
    :type file_path:  str
    :return: list
    :rtype:
    """
    filenames = os.listdir(file_path)
    for i in filenames:
        scr_name = i.split('.')[0]
        _type = i.split('.')[-1]
        file_name_list[_type].append(scr_name)
    return file_name_list


# 文件夹不存在，创建文件夹
def mk_Fol(path):
    """
    检测路径是否存在，不存在则创建路径
    """
    pa = os.path.exists(path)
    if pa is not False:
        pass
    else:
        os.mkdir(path=path)
        return True


# xls_转_xlsx程序，文件夹为程序exc下，转换后自动读取
def xls_To_xlsx(path, f_name, sheet_name):
    """
    excel  .xls 后缀 改成 .xlsx 后缀
    path 文件夹路径
    f 读取文件的文件名
    """
    file_name_be, suff = os.path.splitext(f_name)  # 路径进行分割，分别为文件路径和文件后缀
    # print(file_name_be, suff)
    if suff == '.xls':
        # ui.printf('将对{}文件进行转换...'.format(f_name))
        # print(path + '/' + f)
        data = pd.DataFrame(pd.read_excel(path + '/' + f_name, sheet_name=sheet_name))  # 读取xls文件
        data.to_excel(os.getcwd() + '/exc/' + file_name_be + '.xlsx', sheet_name=sheet_name, index=False)  # 格式转换
        return file_name_be + '.xlsx'
    else:
        pass

def copy_sheet(src_xlsx, ssheetname, dst_xlsx, nsheetname=None):
    if nsheetname == None:
        nsheetname = ssheetname
    try:
        sw = load_workbook(f'{src_xlsx}')
    except KeyError:
        raise KeyError('旧工作簿不存在 The old xlsx is not exists')

    try:
        dw = load_workbook(f'{dst_xlsx}')
    except FileNotFoundError:
        dw = Workbook()

    try:
        sheet = dw[f'{nsheetname}']
    except KeyError:
        sheet = dw.create_sheet(f'{nsheetname}')

    try:
        src_sheet = sw[f'{ssheetname}']
    except KeyError:
        raise KeyError('源工作簿文件不存在该工作簿 The sheet does not exist in the source file')

    # for i in range(1):
    #     sheet.delete_rows(2000)
    for sheet in dw:
        sheet.delete_rows(1, 3000)

    for row in src_sheet.iter_rows():
        # print(row)
        row_list = []
        for cell in row:
            row_list.append(cell.value)
        sheet.append(row_list)
    dw.save(f'{dst_xlsx}')


from distutils.core import setup

setup(
    name='Lshengpackage',  # How you named your package folder (MyLib)
    packages=['Lshengpackage'],  # Chose the same as "name"
    version='0.4.0',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='个人自动化爬虫开源学习',  # Give a short description about your library
    # long_description=open('README.md', 'r', encoding='utf-8').read(),
    author='Lsheng0-0',  # Type in your name
    author_email='1522833718@qq.com',  # Type in your E-Mail
    url='https://lsheng0-0.github.io/',  # Provide either the link to your github or to your website
    download_url='https://github.com/Lsheng0-0/package',  # I explain this later on
    include_package_data=True,
    install_requires=[  # I get to this in a second
        'openpyxl',
        'pandas',
        'PyAutoGUI',
        'pyperclip',
        'opencv-python',
        'Pillow',
        'aircv',
        'numpy',
        'requests'
    ],
    keywords=['游戏', '办公', '自动化', '爬虫'],  # Keywords that define your package best
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.9',
    ], )



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
import os
import sys
import pyautogui
from time import sleep
from Lshengpackage.simulate.adb.Command_adb import command
from Lshengpackage.simulate.mock_findPic import find_image
from Lshengpackage.simulate.adb import Command_adb
# 加载
def load(fol_path, target_path,_system):
    """
        :param img: 循环等待的值
        :type img: img
        :return: 鼠标(1,1),返回 'N'
        :rtype:
        """
    while True:
        sleep(0.1)
        iocn = find_image(fol_path, target_path,_system)
        if iocn is not None:
            sleep(0.1)
            return iocn
        x, y = pyautogui.position()
        if x & y == 0:
            sys.exit()
            # 暂时先这样结束进程
        else:
            pass


def load_click(fol_path, target_path,_system):
    """
    加载点击
    """
    sleep(0.1)
    iocn = load(fol_path, target_path,_system)
    print(iocn)
    if iocn is not None:
        if _system == 'adb':
            sleep(0.1)
            command().tap_work(int(iocn[0]), int(iocn[1]))
        else:
            sleep(0.1)
            pyautogui.click(int(iocn[0]), int(iocn[1]))
            return True
    else:
        return False

def insclick(fol_path, target_path,_system):
    """
    加载点击
    """
    sleep(0.1)
    iocn = find_image(fol_path, target_path, _system)
    if iocn is not None:
        sleep(0.1)
        if _system == 'adb':
            command().tap_work(int(iocn[0]), int(iocn[1]))
            return True
        else:
            pyautogui.click(int(iocn[0]), int(iocn[1]))
            return True
    else:
        return False


# -*coding:utf-8 -*-
# !/usr/bin/env python

from PIL import ImageFile
from PIL import Image
import os


class command:
    def dev(self):
        # 查看当前链接设备
        com = os.popen('adb devices').read()
        return com

    #
    def state(self):
        # 返回连接状态
        com = os.popen('adb get-state').read()
        return com

    #
    def connect(self, ip):
        # 连接ip+端口号
        com = os.popen('adb connect {}'.format(ip)).read()
        return com

    #
    def insert(self, text):
        com = os.system('adb shell input text {}'.format(text))  # 输入文本
        return com

    def log(self):
        # 查看日志
        com = os.popen('adb logcat').read()
        return com

    def kill(self):
        # 结束adb服务
        com = os.system('adb kill-server')
        return com

    def star(self):
        # 开始adb服务
        com = os.system('adb start-server')
        return com

    def install(self, apk_name):
        # 安装软件
        com = os.system('adb install -r {}.apk'.format(apk_name))
        return com

    def uninstall(self, apk_name):
        # 卸载
        com = os.system('adb uninstall {}.apk'.format(apk_name))
        return com

    def update(self, file_name, path_phone):
        # 上传SDCard/../..手机端路径
        com = os.system('adb push {} {}'.format(file_name, path_phone))
        return com

    def download(self, file_name):
        # 下载
        com = os.system('adb uninstall {}'.format(file_name))
        return com

    def scr(self, path_pic_name):
        # 屏幕截图到手机根目录
        com = os.system('adb shell screencap -p /sdcard/{}.png'.format(path_pic_name))
        return com

    def video_scr(self, video_name):
        # 录屏，默认mp4格式
        com = os.system('adb shell screenrecord /sdcard/{}.mp4'.format(video_name))
        return com

    def cut_scr(self, fol_path):
        # 屏幕截图到本地
        # pic_name:屏幕截图生成地址+名称，默认为手机的根目录,默认的来
        # path为文件夹目录下
        self.scr(fol_path.split('\\')[-1])
        com = os.system("adb pull /sdcard/{}.png {}".format(fol_path.split('\\')[-1], fol_path))
        ImageFile.LOAD_TRUNCATED_IMAGES = True
        return com

    def spec_scr(self, pic_path, int_x1, int_y1, int_x2, int_y2):
        """
        指定截图保存
        左上角的点到右下角的点
        """
        self.cut_scr(pic_path)
        img = Image.open(pic_path)
        # (4)将图片验证码截取
        code_image = img.crop((int_x1, int_y1, int_x2, int_y2))
        code_image.save(pic_path)  # 原地址重写
        return True

    def tap_work(self, x, y):
        """
        模拟点击操作
        """
        com = os.system('adb shell input tap {} {}'.format(x, y))
        return com

    def swip_work(self, x, y, x2, y2):
        """
        模拟滑动操作
        """
        com = os.system('adb shell input swipe {} {} {} {}'.format(x, y, x2, y2))
        return com

    def get_ui(self, path):
        re = os.popen('adb shell uiautomator dump /sdcard/ui.xml')  # 获得屏幕控件信息
        re = os.popen(r'adb pull /sdcard/ui.xml {}+ui.xml'.format(path))  # 获得屏幕控件信息
        return re
